#
# spec file for package gopls
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gopls
Version:        0.17.0
Release:        1.1
Summary:        Go LSP protocol language server
License:        Apache-2.0 AND MIT AND BSD-3-Clause
Group:          Development/Tools/Other
URL:            https://pkg.go.dev/golang.org/x/tools/gopls
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.18

%description
gopls (pronounced "Go please") is the official Go language server developed
by the Go team. It provides IDE features to any LSP-compatible editor.

%prep
%autosetup -a 1
# Upstream Go x/tools monorepo has a subdir per tool.
# Unlike most Go applications at the repository root,
# package x/tools sources as subdir/ so we can include
# LICENSE file from monorepo top level dir.
mv LICENSE %{name}
# vendor dir must also be moved to subdir to be detected
mv vendor %{name}

%build
# Change to subdir, see comment in prep phase
cd %{name}
%ifnarch ppc64
export GOFLAGS="-buildmode=pie"
%endif
go build

%check
# Account for subdir, see comment in prep phase
# Execute the binary as a basic check
./%{name}/%{name} --help

%install
# Account for subdir, see comment in prep phase
install -D -m 0755 %{name}/%{name} "%{buildroot}/%{_bindir}/%{name}"

%files
# Account for subdir, see comment in prep phase
%doc %{name}/README.md
%license %{name}/LICENSE
%{_bindir}/%{name}

%changelog
* Wed Dec 11 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 0.17.0:
  * gopls: update go.mod for v0.17.0-pre.5
  * internal/typesinternal: rollback of Zero{Value,Expr} for gopls
  * gopls: update go.mod for v0.17.0-pre.4
  * gopls/internal/golang: support extract variable at top level
  * gopls/internal/golang: ignore effects for change signature refactoring
  * gopls/internal/golang: add "Extract constant" counterpart
  * gopls/internal/golang/stubmethods: refine crash into bug report
  * gopls/internal/golang: don't offer to move variadic parameters
  * gopls/internal/test/marker: add reproducers for moveparam bug bash bugs
  * gopls/internal/analysis/yield: add comment about dataflow
  * gopls/internal/golang: avoid crash in lookupDocLinkSymbol
  * gopls/internal/golang/completion: fix crash with extra results
  * gopls/internal/settings: enable 'waitgroup' analyzer
  * gopls/internal/golang: Disable test generation for generic functions
  * gopls/internal/analysis/yield: peephole-optimize phi(false, x)
  * gopls/internal/golang: fix folding range for function calls
  * gopls/internal/golang/completion: add alias support for literals
  * gopls/internal/undeclaredname: add missing colon when appropriate
  * gopls/internal/golang: simplify package name collection in add test
  * gopls: update go.mod for v0.17.0-pre.3
  * gopls/internal/golang: refactor.extract.variable: allow all exprs
  * gopls/internal/cache/methodsets: refine crash for missing object path
  * gopls/internal/golang: refine crash golang/go#70553
  * gopls/internal/golang: change signature via renaming 'func'
  * gopls/internal/golang: support parameter movement refactorings
  * gopls/doc/features: enable and document source.addTest code action
  * gopls/internal/golang: improve test package name selection for new file
  * gopls/internal/golang: don't lose ... when split/joining variadics
  * gopls/internal/crash: don't crash in xrefs on out of bound nodes
  * gopls/internal/golang: preserve copyright and build constraint
  * gopls/internal/test/marker: add defloc, to bind positions by definition
  * gopls/internal/test/marker: document named parameters
  * gopls/internal/golang/extract: preserve comments in extracted block
  * gopls/internal/test/marker: ignore diags in fixedbugs/issue59944.txt
  * gopls/internal/golang: fix gopls hover doc link
  * gopls/doc/contributing.md: update expectations
  * gopls/internal/analysis/undeclaredname: merge into CodeAction
  * gopls/internal/test/marker: generalize codeaction with named args
  * gopls/internal/golang: don't try to inline dynamic calls
  * gopls/internal/cache: refine bug reports for inconsistent dep view
  * gopls/internal/cache: fix handling of cgo standalone files
  * gopls/internal/test: synchronize notifications during commands
  * gopls/internal/cache: failure to extract diagnostic fixes is an error
  * gopls/internal/server: remove spurious Async in legacy RunGoVulncheck
  * gopls/internal/cache: use a named bool type for allowNetwork
  * gopls/internal/protocol: add DocumentURI.DirPath
  * gopls/internal/cache: simplify usage of snapshot.GoCommandInvocation
  * gopls/internal/analysis/yield: analyzer for iterator (yield) mistakes
  * gopls/internal/cache: id command-line-arguments packages using GoFiles
  * gopls/internal/golang: more idiomatic result naming in extract
  * gopls/internal/golang: special handling for input context.Context
  * gopls/internal/golang, go/ssa: remove unnamed input parameter
  * gopls: update go.mod for v0.17.0-pre.2
  * gopls/internal/golang: fix bad slice append in function extraction
  * gopls/codeaction: fix panic when removing unused parameters with syntax errors.
  * gopls/internal/server: don't call window/showDocument if unsupported
  * gopls/internal/golang: add missing imports in foo_test.go
  * gopls/internal/server: revert the gopls.run_govulncheck command
  * gopls/internal/golang: avoid crash in hover on field of non-struct
  * gopls: update go.mod for v0.17.0-pre.1
  * all: update codereview.cfg for gopls-release-branch.0.17
  * gopls/internal/golang: refine crash report golang/go#69362
  * gopls/internal/golang: support add test for receiver w/o constructor
  * gopls/internal/golang: semtok: use type information consistently
  * gopls/internal/protocol: upgrade to latest LSP
  * gopls/internal/golang: strength reduce ComputeImportFixEdits
  * gopls/internal/golang: show package attributes on hover
  * gopls/doc: add missing doc link
  * gopls/internal/cache: guard against malformed paths in port.matches
  * gopls/internal/semtok: change types.Named to types.Basic for iota, true, and false
  * gopls: update x/telemetry to pick up fix for countertest.ReadCounter
  * gopls/internal/server: don't interact with os.UserConfigDir from tests
  * gopls/internal/cache: ensure GO111MODULE is unset in GOPATH tests
  * gopls/internal/golang: run testcases as subtests
  * gopls/internal/golang: add testcase handling for func with error returns
  * gopls/internal/cache: log go env in TestZeroConfigAlgorithm
  * gopls/internal/golang: consolidate imports from both file in qualifier
  * gopls/internal/golang: support generating test for functions
  * gopls/internal/test/integration/workspace: fix TestStdWorkspace
  * gopls/internal/golang: generate test name for selected function/method
  * gopls/internal/golang: use correct imports in HTML pkg doc links
  * gopls/internal/test: fix path to local go in integration tests
  * gopls/internal/golang: add source code action for add test
  * Revert "gopls/internal/analysis: disable ssa/ir analyzers on range-over-func"
  * gopls: update honnef.co/go/tools (staticcheck) to v0.5.1
  * gopls/internal: stubcalledfunction: improve logic of selecting insert position
  * gopls/internal/template: fix completion token boundary conditions
  * gopls/internal/cache: share type checking with analysis
  * gopls/internal/cache/parsego: support lazy object resolution for Files
  * gopls/internal/cache: memoize cache keys
  * gopls/internal/cache: async pull diagnostics and joined analysis
  * gopls/release: remove unused(?) script
  * gopls/internal/cache: avoid reporting bugs when go/packages has errors
  * gopls/internal/settings: remove "allowImplicitNetworkAccess"
  * gopls/internal/cache: refine a bug report related to package metadata
  * gopls/internal/cache: refine bug reports
  * gopls/internal/telemetry/cmd/stacks: print double-claimed stacks
  * gopls/internal/test/marker: rename s/suggestedfix/quickfix/
  * gopls/internal/cache: add tolerance for builtin test variants
  * gopls: allow for asynchronous request handling
  * gopls/internal/telemetry/cmd/stacks: fix bad tmpreaper interaction
  * gopls: remove cruft
  * gopls/internal: CodeAction:  quickfix to generate missing method
  * gopls/internal/cache/analysis: lazily resolve the import map
  * gopls/internal/test/integration/bench: add a pull diagnostics benchmark
  * gopls/doc/features: add index of supported Code Actions
  * gopls: add initial support for pull diagnostics
  * gopls/internal/cache: use packageHandles to hold an active package cache
  * gopls/doc/codelenses: fix link typo
  * gopls/internal/golang/stubmethods: rename analysis/stubmethods
  * gopls/internal/analysis/stubmethods: merge into CodeAction
  * gopls/internal/cache: memoize dependent hash on analysisNode
  * gopls/internal/cache: express packageHandle as a state machine
  * gopls/internal/test/marker: update regression test issue68918.txt
  * gopls/internal: fix extract refactor for cases with anonymous functions
  * gopls/internal/server: CodeAction: interpret Only=[] as [QuickFix]
  * gopls/rename: include filename in error message
  * gopls/completion: tweak fuzz handling to make its own MethodSet
  * gopls: update x/telemetry to pick up fix for golang/go#69681
  * gopls/internal/test/integration/bench: add an IWL test that opens files
  * gopls/internal/cache: remove unnecessary active package check
  * gopls/internal/cache: add a few checks for context cancellation
  * gopls/internal/cache: join concurrent package batch operations
  * gopls: disable ast.Object resolution wherever possible
  * gopls/internal/server: allow suppression of showDocument
  * gopls/internal/protocol/command: simplify ApplyFix
  * gopls/internal/golang: CodeAction: split into producers
  * gopls/internal/telemetry/cmd/stacks: show build failure stderr
  * gopls/internal/protocol/command: remove nuisance error handling
  * gopls/internal/cache: add telemetry counter for GOPACKAGESDRIVER
  * gopls/internal/test/integration: skip BenchmarkPackages with -short
  * gopls/internal/cache: build the import map lazily during type checking
  * gopls/internal/telemetry/cmd/stacks: display closed issues white
  * gopls/internal/golang: Definition: jump to assembly
  * gopls/internal/telemetry/cmd/stacks: predicate de-duplication
  * gopls/internal/telemetry/cmd/stacks: fix two bugs
  * gopls: rm GofumptFormat from internal/settings
  * gopls/internal/telemetry/cmd/stacks: generate CodeSearch links
  * gopls/internal/settings: use CodeActionKind hierarchy
  * gopls: bump gofumpt to 0.7.0
  * gopls/internal/lsp/source: put testing.T/B first when extracting
  * gopls/internal/golang: Definitions: support renaming imports in doc links
  * gopls/internal/server: fix build following semantic merge conflict
  * gopls/internal: test discovery
  * gopls/internal/golang: Highlight: work around go/types bug
  * gopls: use Func.Signature everywhere
  * x/tools/gopls: delete code obsoleted by go1.23
  * internal/golang: add a fast path for FormatVarType with gopls at 1.23
  * gopls/internal/settings: add missing deep cloning in Options.Clone
  * gopls/go.mod: update the go directive to 1.23.1
  * gopls: fix non-constant format strings
  * gopls: update x/telemetry dependency
  * gopls/internal/test/marker: simplify completion markers
  * gopls: report semantic tokens of top-level type constructor modifiers
  * gopls/internal/cache: add a note about GOMEMLIMIT and ballasts
  * gopls/internal/cache: add a 100MB ballast to reduce GC CPU
  * gopls/internal/util/lru: make lru.Cache generic
  * gopls: increment the telemetryprompt acceptance counter for each session
  * gopls/internal: implement Packages command
  * gopls/internal: implement Modules command
  * gopls/internal/settings: rename goTest code action to source.test
  * gopls/internal/cache: remove spurious assertions
  * gopls/internal/golang: downgrade assertion in methodsets index
  * gopls: enhance read/write access distinction in document highlighting for symbols
  * gopls/internal/analysis: add skipped analysis simplify on generated code
  * gopls/internal/telemetry/cmd/stacks: use authentication token
  * gopls/doc/features: fix prominent typo
  * gopls/doc: delete commands.md
  * gopls/internal/golang: add "Browse gopls features" code action
  * gopls/internal/cmd: redesign codeaction subcommand
  * gopls/doc/features: more doc tweaks
  * gopls: update x/telemetry dependency
  * gopls/internal/protocol/command: draft Packages/Modules API
  * gopls/completion: prefer rangeable funcs in range statements
  * gopls/internal/analysis/fillswitch: use qualified type names
  * gopls/internal/golang: provide version info for stdlib in pkgdoc
  * gopls/internal/server: add counters to inform v0.17.0
  * gopls/doc: respond to Hana's review of CL 583316
  * gopls/doc: document all of gopls' features
  * gopls/internal/golang: provide version info for stdlib fields
  * gopls/internal/analysis/fillstruct: use package name (not path) in UI
  * gopls/internal/golang: splitlines: s/parameter/arguments/ in CallExpr
  * gopls/internal/golang: splitlines: remove workaround for golang/go#68202
  * gopls/internal/golang: don't panic when findKeyword fails
  * gopls/internal/server: conditionally prompt for telemetry
  * gopls/internal/golang: provide version info for stdlib methods
  * gopls/internal/golang: provide available version info in stdlib hover
  * gopls/internal/golang/completion: fix package clause completion suffix
  * gopls/internal/golang: s/return values/results/
  * gopls/internal/fuzzy: move the fuzzy package to gopls
  * gopls/internal/cache: lift package caching to forEachPackage
  * gopls/matcher: don't give bonus to case insensitive match
  * gopls/completion: don't take address of interfaces for "%%p" values
  * gopls/internal: add code action "extract declarations to new file"
  * gopls: skip failing tests on wasm/wasip1
  * gopls/internal/golang: fix hovering from the builtin file
  * gopls/internal/settings: remove fieldalignment analyzer
  * gopls/internal/golang: strip @v1.2.3 suffix from pkgdoc URLs
  * gopls/internal/analysis/simplifyrange: reenable on range-over-func
  * gopls/internal/settings: define InlayHints enum
  * gopls/internal/settings: move CodeActionKind values from protocol
  * gopls/internal/server: fix CSS typo
  * gopls/internal/settings: minor cleanups
  * gopls/doc/generate: treat LinksInHover as an enum
  * gopls/doc/assets: create dummy submodule for image files
  * gopls/doc/release: finalize v0.16.0 release notes
  * gopls/internal/settings: move CodeLensSource from protocol
  * gopls/internal/test/integration/misc: skip asm test unless a{rm,md}64
* Thu Sep  5 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 0.16.2:
  * gopls: update go.mod for v0.16.2-pre.2
  * gopls: update x/telemetry dependency
  * gopls: increment the telemetryprompt acceptance counter for each session
  * gopls: add x/tools replace directive
  * gopls: update go.mod for v0.16.2-pre.1
  * gopls: update x/telemetry dependency
* Tue Jul  2 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 0.16.1:
  * gopls: update go.mod for v0.16.1-pre.1
  * gopls/internal/server: add counters to inform v0.17.0
  * gopls/internal/golang: strip @v1.2.3 suffix from pkgdoc URLs
  * internal/typeparams: fix crash in interface hover with empty type set
  * gopls/internal/golang/completion: fix package clause completion suffix
* Thu Jun 20 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 0.16.0:
  * gopls: update go.mod for v0.16.0-pre.3
  * gopls/internal/settings: move CodeLensSource from protocol
  * gopls: update go.mod for v0.16.0-pre.2
  * gopls/internal/golang: Hover: use internal pkg doc viewer
  * gopls/internal/golang: improve ergonomics of "Browse documentation"
  * gopls/internal/settings: simplify SetOptions
  * gopls/internal/lsp/source: ignore lambdas in call hierarchy
  * gopls/internal/golang: s/View/Browse/ for browser-based features
  * gopls: expand on documentation about version support changes
  * gopls/internal/test/integration/misc: skip ASM assertions on risc64
  * gopls/doc/release: update gopls release notes for language support
  * gopls/doc/emacs.md: use more precise before-save terminology
  * gopls: update go.mod for v0.16.0-pre.1
  * all: update codereview.cfg for gopls-release-branch.0.16
  * gopls: update x/telemetry dependency
  * gopls: update x/telemetry dependency
  * gopls: fix StmtToInsertVarBefore for switch stmts
  * gopls/internal/protocol/command/gen: omit unnecessary MarshalArgs calls
  * gopls/internal/golang: s/Show/View/ for web-based reports
  * gopls/internal/server: return a non-nil slice for empty token result
  * gopls/internal/golang: factor the 3 web reports
  * gopls/internal/golang: Web, an abstraction of server.web
  * gopls/internal/server: simplify FreeSymbols plumbing
  * gopls/internal/cache: stop module cache refresh on view shutdown
  * gopls/internal/test/integration/misc: fix build
  * gopls/internal/golang: add "Show assembly of f" code action
  * gopls/internal/test/integration: style tweaks to CodeAction
  * gopls/internal/protocol/command: use gopls.foo form everywhere
  * gopls/internal/cmd: cleanup progress handling
  * gopls/internal/test: add test case for parameter rename match import
  * gopls/internal/server: fix regression in organize imports code action
  * gopls/internal/cache: fix module resolver cache refreshing
  * gopls/rename: Fix spurious package name conflicts.
  * gopls: warn about Go 1.19 and Go 1.20
  * gopls/internal/filecache: suppress gc in tests
  * gopls/internal/cache: suppress "internal" import check on Bazel
  * gopls/internal/cache: check viewMap before altering views
  * gopls/internal/test/marker: simplify seedCache file
  * gopls/internal/cache: use a better view in viewOfLocked
  * gopls: make tests tolerant of new go/types error format
  * gopls/internal/test/marker: seed the cache before running tests
  * Revert "gopls/internal/settings: enable semantic tokens by default"
  * gopls/internal/golang: OutgoingCalls: fix crash on unsafe.Slice
  * gopls/internal/cache: improve missing import error message
  * gopls/internal/golang: skip TestFreeRefs on js
  * gopls/internal/server: support InsertReplaceEdit completion
  * gopls/internal/golang: unexport more declarations
  * gopls/internal/server: avoid VS Code lightbulb
  * gopls: initial support for godebug directive in go.mod and go.work
  * gopls/doc: split codelenses out of settings
  * gopls/internal/analysis/simplifyrange: suppress on range-over-func
  * gopls/internal/protocol: customize InsertReplaceEdit JSON unmarshal
  * gopls/internal/golang: unexport several functions
  * gopls/internal/test/integration: fix race in TestGCDetails_Toggle
  * gopls/doc: tidy up analyzer documentation
  * gopls/internal/golang: fix bug in freeRefs algorithm
  * gopls/internal/golang: "Show free symbols" code action
  * gopls/internal/golang: remove test debugging aix-ppc64 issue
  * gopls/internal/protocol: separate CodeLens from Command; document
  * gopls: remove dead code
  * gopls: upgrade x/telemetry to pick up CL 586195
  * gopls/internal/test/marker: fix analyzers.txt test that requires cgo
  * gopls/internal/protocol: rename DocumentChange{s,}
  * gopls: support four kinds of DocumentChanges
  * gopls/internal/cache: use 1 not 0 for missing line/col info
  * gopls/internal/cache: support overlays
  * gopls/doc/generate: add link anchors to each setting
  * gopls: further minor generator simplifications
  * gopls: upload from telemetry.Start, rather than upload.Run
  * gopls: upgrade x/telemetry to latest
  * gopls/internal/settings: annotate TestVetSuite with NeedsTool("go")
  * gopls/internal/golang: fix another crash in RenderPackageDoc
  * gopls/internal/golang: RenderPackageDoc: fix param truncation crash
  * gopls/doc/release: add release notes for struct tag hover info
  * gopls/internal/golang: show struct tag when hovering over fields
  * gopls/internal/server: discard non-file scheme workspace folder URIs
  * gopls/internal/cache: fix bug.Report converting Diagnostic positions
  * gopls/internal/test/integration/misc: disable another staticcheck test
  * gopls/internal/settings: add framepointer,sigchanyzer analyzers
  * gopls/internal/test/integration/misc: disable staticcheck test
  * gopls/internal/test: avoid std assumptions in range-over-func test
  * gopls: rationalize code generation
  * gopls/internal/protocol: rationalize edit helpers
  * gopls/internal/golang: simplify "rewrite" code actions
  * gopls/internal/cache: simplify Snapshot Go commands
  * gopls/internal/analysis: disable ssa/ir analyzers on range-over-func
  * gopls/internal/protocol: add links to LSP spec
  * gopls/internal/golang: fix nil panic in InlayHint
  * gopls/internal/golang/completion: fix the isEmptyInterface predicate
  * gopls/internal/cache: use language versions when validating Go version
  * gopls: normalize logging attributes
  * gopls/internal/golang: fix resolution of in-package implementations
  * gopls/internal/cache: add more assertions for golang/go#60890
  * gopls/internal/golang: check the comment range before emiting semantic tokens
  * Revert "gopls/internal/test/integration/misc: reenable staticcheck test"
  * gopls/internal/test/integration/misc: reenable staticcheck test
  * gopls: fix a couple places where temporary files are not removed
  * gopls/internal/settings: deprecate "allowImplicitNetworkAccess"
  * gopls/internal/settings: remove support for "allowModfileModifications"
  * gopls/internal/settings: enable semantic tokens by default
  * gopls/internal/settings: remove experiments
  * gopls/internal/golang: allow "query" CodeActions on generated files
  * gopls/internal/golang: RenderPkgDoc: elide parameters 4+ in index
  * gopls/internal/settings: update stale documentation for "symbolScope"
  * gopls: eliminate the hooks package
  * gopls/internal/server: don't reset views if configuration did not change
  * gopls/internal/cmd: check: print RelatedInformation
  * gopls/doc: relnote for hover & definition over doc links
  * gopls/internal/test/marker: fix {hover/def}/comment tests
  * gopls/internal/cache: fail loudly on command-line-arguments modules
  * gopls/internal/golang: support hover and definition operations over doc links
  * gopls/internal/server: avoid duplicate diagnoses and loads
  * gopls/internal/cache: don't log packages when selectively reloading
  * gopls: reduce noisy error messages
  * gopls/internal/test: skip integration tests on linux-ppc64-power9osu
  * gopls/internal/cache: add debug assertions to refine golang/go#66732
  * gopls/internal/cache: avoid panic when the primary diagnostic is broken
  * gopls/internal/telemetry/cmd/stacks: improve summary
  * gopls/internal/golang: RenderPkgDoc: fix anchors for promoted methods
  * gopls/internal/server: report HTTP panics via telemetry
  * gopls/internal/cache: analysis: repair start/end and refine bug report
  * gopls/internal/golang: RenderPkgDoc: add <title> element
  * gopls/internal/golang: RenderPkgDoc: navigational <select>
  * gopls/internal/test/marker/testdata: skip hover size tests on 32-bit arm
  * gopls/internal/golang: Hover: show wasted %% of struct space
  * gopls/internal/test/integration/misc: fix flaky test
  * gopls/internal/analysis/fillreturns: skip test if gotypesalias=1
  * gopls/internal/cache: fix crash in snapshot.Analyze with patch versions
  * gopls/internal/server: filter diagnostics to "best" views
  * gopls/internal/test/integration: add a WriteGoSum run option
  * gopls/internal/golang: RenderPackageDoc: fix doc links
  * gopls/internal/test: temporarily disable staticcheck with gotypesalias=1
  * gopls/internal/golang: RenderPackageDoc: emit anchors for var/const
  * gopls/internal/server: "view package doc" of package under test
  * gopls/internal/golang: view pkg doc: display when "disconnected"
  * gopls/doc/release/v0.16.0.md: augment notes for "view pkg doc"
  * gopls/internal/settings: enable "unusedwrite" analyzer
  * gopls/internal/golang: hover: show size/offset info
  * gopls/internal/golang: work around bug in go/doc
  * gopls/internal/test: option to suppress LSP logs on failure
  * gopls: add explicit Unalias operations
  * gopls: update x/vuln to 1.0.4
  * gopls/internal/server: redo completion counters
  * gopls: use slices package for reverse slice
  * gopls/internal/golang: don't suggest removeparam when there are errors
  * gopls/internal/golang: support removing unused parameters from methods
  * gopls/internal/golang: fix build breakage due to semantic conflict
  * gopls/internal/server: add "View package documentation" code action
  * gopls/internal/test/marker: remove runtime.GOROOT from format.txt case
  * gopls/internal/cache: rename methods on Package
  * gopls: fix test failures due to quoting of names in go/types errors
  * gopls: repair premature commit of 562248
  * gopls: Measure the efficacy of completions
  * gopls/internal/server: update telemetry prompt link
  * gopls/internal/golang: fix crash in package references
  * gopls/internal/server: fix crash in SignatureHelp
  * gopls/internal/analysis/stdversion: suppress before go1.21
  * gopls/internal/analysis/stdversion: set RunDespiteErrors
  * gopls/internal/golang/completion: honor std symbol versions (imported)
  * gopls/internal/server: set -mod=readonly when checking for upgrades
  * gopls/internal/cache: avoid go/types panic on version "go1.2.3"
  * gopls/internal/cache: fix spurious diagnostics in multi-root workspaces
  * gopls/internal/cache: add assertions for telemetry crash
  * gopls/internal/golang/completion: honor std symbol versions (unimported)
  * gopls/internal/server/semantic: highlight the doc links in comments
  * gopls/internal/analysis/stdversion: report refs to too-new std symbols
  * gopls/internal/cache: prune broken edges to command-line-arguments pkgs
  * gopls/protocol: update LSP to latest version
  * gopls/internal/cache: add debug assertions for bug report
  * gopls/doc: address additional comments on workspace.md
  * gopls/internal/analysis: add fill switch cases code action
  * gopls/internal/test: add test for NPE in control flow highlighting
  * gopls: add non nil if check around function result highlight
  * gopls: implement code action to split/group lines
  * gopls: upgrade dependencies following the v0.15.0 release
  * gopls/doc: update workspace documentation for zero-config gopls
  * gopls: rationalize "deref" helpers
  * gopls/internal/test/marker: add a test for initialization cycle errors
  * gopls/internal/cache: don't create Views for vendored modules
  * gopls/internal/cache: fix two bugs related to workspace packages
  * gopls/internal/golang: highlight typeswitch break correctly
  * gopls/internal/settings: default "includeReplaceInWorkspace" to false
  * gopls/internal/test/integration/fake: set LSP client name
  * gopls/internal/golang: enable bug.Report in semantic tokens
  * gopls/internal/golang: add semantic tokens for control labels
  * gopls/internal/golang: SemanticTokens: edits for clarity
  * gopls/internal/cache: remove parsego.* aliases
  * gopls/release: remove obsolete validateHardCodedVersion
  * gopls/internal/server: fix a (mostly) benign race in diagnostics
  * gopls/internal/server: disambiguate diagnostics by OS,ARCH
  * gopls/internal/test/integration: ignore telemetry prompt in assertion
  * gopls/internal/golang: remove a use of panic for flow control
* Mon Apr 15 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 0.15.3:
  * gopls: update go.mod for v0.15.3-pre.2
  * gopls/internal/server: don't reset views if configuration did not change
  * gopls: update go.mod for v0.15.3-pre.1
  * gopls/internal/cache: add debug assertions to refine golang/go#66732
  * gopls/internal/cache: analysis: repair start/end and refine bug report
  * gopls/internal/cache: avoid panic when the primary diagnostic is broken
  * internal/check: filter out too-new Go versions for type checking
  * gopls/internal/cache: fix crash in snapshot.Analyze with patch versions
  * gopls/internal/server: filter diagnostics to "best" views
  * internal/imports: fix two "nil pointer in interface" bugs
  * all: add replace directive to help stage the v0.15.3 release
  * gopls: fix test failures due to quoting of names in go/types errors
* Mon Mar 11 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 0.15.2:
  * gopls: update go.mod for v0.15.2-pre.2
  * gopls/internal/server: update telemetry prompt link
  * gopls/internal/golang: fix crash in package references
  * gopls/internal/server: fix crash in SignatureHelp
  * gopls: update go.mod for v0.15.2-pre.1
  * gopls/internal/cache: add assertions for telemetry crash
  * gopls/internal/server: set -mod=readonly when checking for upgrades
  * gopls/internal/cache: avoid go/types panic on version "go1.2.3"
  * gopls/internal/cache: fix spurious diagnostics in multi-root workspaces
  * gopls/internal/cache: prune broken edges to command-line-arguments pkgs
* Wed Feb 28 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 0.15.1:
  * gopls: update go.mod for v0.15.1-pre.1
  * gopls/internal/test: add test for NPE in control flow highlighting
  * gopls: add non nil if check around function result highlight
* Mon Feb 26 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 0.15.0:
  * gopls: update go.mod for v0.15.0-pre.5
  * gopls/internal/cache: don't create Views for vendored modules
  * gopls/internal/cache: fix two bugs related to workspace packages
  * gopls/internal/settings: default "includeReplaceInWorkspace" to false
  * gopls: update go.mod for v0.15.0-pre.4
  * gopls/internal/server: disambiguate diagnostics by OS,ARCH
  * gopls: update go.mod for v0.15.0-pre.3
  * gopls/internal/test/integration: slightly more ergonomic FolderSettings
  * gopls/internal/server: fix two bugs related to dynamic configuration
  * gopls/internal/golang: close open file
  * gopls: update x/telemetry dependency to fix crash
  * gopls: record that v0.15 will be the last to support go1.18
  * gopls/internal/settings: add a hidden option to disable zero config
  * gopls/internal/golang: add resolve support for inline refactorings
  * gopls/internal/cache: treat local replaces as workspace modules
  * gopls/internal/cache: check views on any on-disk change to go.mod files
  * gopls: update telemetry
  * gopls/internal/cache: fix crash in analysis
  * gopls/internal/utils/immutable: remove unused Map.Keys
  * gopls/semantic: elide zero-length tokens
  * gopls/doc: audit for types.Alias safety
  * gopls: update go.mod for v0.15.0-pre.2
  * gopls/internal/cache: prime goimports cache asynchronously
  * gopls/internal/cache: share goimports state for GOMODCACHE
  * gopls/internal/test/integration/bench: improve completion benchmarks
  * gopls/internal/test/marker: skip on LUCI solaris builders
  * gopls/internal/test/integration: add a test for an inner go.work file
  * gopls/internal/settings: deprecate "allowModfileModifications"
  * gopls/internal/cache: remove findWorkspaceModFile
  * gopls/internal/cache: detect and reinit on workspace vendor changes
  * gopls/internal/golang: add missing check for nil funcBody
  * gopls/internal/golang: move Go semantic tokens out of server
  * gopls: remove unused parameters
  * gopls/internal/cache: add assertions for export data inconsistency
  * gopls/internal/cache: support workspace vendoring
  * gopls/internal/golang: downgrade bug.Reportf for missing builtin
  * gopls/internal/cache: allow command-line-package >1 CompileGoFiles
  * gopls/internal/cache/metadata: assert graph is acyclic
  * gopls/internal/golang: hover: show embedded fields
  * gopls/internal/lsp/source: highlight returns correctly
  * gopls: enable crashmonitor for unexpected crashes
  * gopls: update third party dependencies
  * gopls/internal/test/marker: reject "module testdata"
  * gopls/internal/analysis/undeclaredname: improve fix name
  * gopls/internal/test/marker/testdata: move test to correct location
  * gopls/internal/cache/imports: simplify importsState invalidation
  * gopls/internal/golang: hover: show type's methods after doc comment
  * gopls: update x/telemetry dependency
  * gopls/internal/test/integration/bench: fix broken benchmarks
  * gopls/internal/cache: memoize the view filter func
  * gopls/internal/cache: skip TestZeroConfigAlgorithm on wasm
  * gopls/doc/emacs.md: explain how to organize imports automatically
  * gopls/internal/golang: don't bug.Report repaired ASTs in hover
  * gopls/internal/test: await quiescence in TestInconsistentVendoring
  * gopls/doc: s/source/golang/ in the SVG file
  * gopls: manual tweaks after the lsp/ -> . rename
  * gopls/internal/protocol/command: move from ../lsp
  * gopls/internal/protocol: move out of lsp/
  * gopls/internal/cache: move out of lsp/
  * gopls/internal/golang: move from lsp/source
  * gopls/internal/lsprpc: move out of lsp/
  * gopls: use relative watched file patterns if supported
  * gopls/internal/progress: simplify API
  * gopls/internal/progress: move from lsp/
  * gopls/internal/telemetry/cmd/stacks: include client name in report
  * gopls/internal/lsp/lsprpc: radically reduce API
  * gopls/doc: add Helix editor documentation for gopls
  * gopls/internal/test/integration: add regtest for hover crash
  * gopls/internal/lsp/cache: clean up public API
  * gopls/internal/lsp/cache: don't report a bug for standalone test files
  * gopls/internal/lsp/source: address problems detected by staticcheck
  * gopls/internal/test/marker: re-enable some tests
  * gopls: consolidate analyzers, eliminating "convenience" analyzers
  * gopls/internal/lsp/cache: allow versions of form "go1.2.3"
  * gopls/internal/lsp/cache: fix bug reports from toGobDiagnostics
  * gopls/internal/lsp/source: move Go CodeActions logic from server
  * gopls/internal/lsp/source: show promoted methods in hover
  * gopls/doc/design: rewrite the architecture overview
  * gopls/internal/version: amend the year in a recent copyright header
  * gopls/internal/lsp/source: factor edit conversion utils
  * gopls/internal/server: analyze widest packages for open files
  * gopls: add a main.version variable to override the version at linktime
  * gopls/internal/lsp/source/completion: infer parameter types
  * gopls/internal/lsp/source: fix Fix titles
  * gopls/internal/test/marker: fix test breakage due to semantic conflict
  * gopls/internal/analysis/unusedparams: eliminate false positives
  * gopls/internal/lsp/protocol: fix TestURIFromPath on windows
  * gopls/internal/test/marker: update skip comment for addgowork.txt
  * gopls/internal/server: simplify DiagnoseFiles to avoid a race
  * gopls/internal/test/integration: fix flakiness of TestResolveImportCycle
  * gopls/internal/lsp/protocol: deliver log messages in order
  * gopls/internal/test/marker: skip on solaris-amd64-oraclerel
  * gopls: simplify gopls command configuration
  * gopls/internal/test/marker: regenerate golden data
  * gopls/internal/lsp/source/stub: trim version suffix from module path
  * gopls/internal/lsp/cache: (re-)ensure clean shutdown
  * gopls/internal/lsp/source/completion: support postfix completion (iferr,
  * gopls/internal/lsp/source: add receiver name to stubbed methods
  * gopls/internal/test: skip marker tests on darwin builders if -short
  * gopls: update go.mod for v0.15.0-pre.1
  * all: update codereview.cfg for gopls-release-branch.0.15
  * gopls/internal/lsp/cache: address additional comments from CL 553095
  * gopls/internal/cmd: factor three loops in fix subcommand
  * gopls/internal/lsp/cache: simplify critical errors
  * gopls/internal/lsp/cache: don't scan for modules when defining a view
  * gopls/internal/lsp/cache: remove validBuildConfiguration
  * gopls/stub: support for method generation with same name but different receiver
  * gopls/internal/lsp/source/completion: complete return snippet
  * gopls/internal/lsp/cache: add dynamic build tag support
  * gopls/internal/lsp/source: simplify SuggestedFix plumbing
  * gopls/internal/server: simplify fileOf (née beginFileRequest)
  * gopls/internal/lsp/cache: add support for checking views from tests
  * gopls/internal/lsp/cache: associate env with folders, not views
  * gopls/internal/lsp/cache: finish integrating the zero-config algorithm
  * gopls/internal/lsp/cache: don't preserve sequence IDs in updated views
  * gopls/internal/lsp/cache: switch to new bestViewForURI logic
  * gopls/internal/lsp/cache: add views for unused modules in selectViews
  * gopls/internal/work: fix crash during go.work completion
  * gopls/internal/lsp/cache: add the zero-config algorithm, and a unit test
  * gopls/internal/lsp/cache: simplify view definitions
  * gopls/internal/lsp/cache: reconcile view modes and workspace packages
  * gopls/internal: remove myers diff implementation from gopls
  * gopls/internal: remove old diff
  * gopls/internal/server: print stderr in go mod vendor error message
  * gopls/internal/server: rewrite the server diagnostic tracking
  * gopls/internal/lsp/cache: do not block View.Shutdown on Snapshot work
  * gopls/internal/lsp/cache: allow "" or "null" Diagnostics.Data
  * gopls: remove dead types and fields
  * gopls/internal/lsp/protocol: request.params is optional
  * gopls/internal/lsp/source: rename: update the doc link associated with the object
  * gopls/internal/test: set GOPACKAGESDRIVER=off for new marker tests
  * gopls/internal/test/marker: minor clean up of marker test doc
  * gopls/internal/lsp/source: hovering over broken packages is not an error
  * gopls/internal/analysis/fillstruct: don't panic with invalid fields
  * gopls/internal/util/goversion: warn about EOL for Go 1.18
  * gopls/internal/settings: remove MemoryMode option
  * gopls/protocol: Allow AnnotatedTextEdits
  * gopls/internal/analysis/stubmethods: fix OOB panic in fromValueSpec
  * gopls/internal/lsp/protocol: report panics in RPC goroutines
  * gopls/internal: don't bug.Report when given an invalid position
  * gopls/internal/lsp/source: forgive inliner failures in ill-typed code
  * gopls/internal/lsp/source: improve method hover
  * gopls/internal/server: tidy imports, fix build
  * gopls/internal/lsp/protocol: eliminate NonstandardRequest
  * gopls/internal/analysis: improve analyzer docs
  * gopls/internal/lsp/source: add test for rename spurious shadowing
  * Revert "gopls/internal/server: rewrite the server diagnostic tracking"
  * gopls/doc: add a note updating the original design doc
  * gopls/internal/server: rewrite the server diagnostic tracking
  * gopls/internal/lsp/cache: move gc_details toggle state to the snapshot
  * gopls/internal/cmd: remove gopls.run_vulncheck example
  * gopls/internal/lsp/cache/parsego: clamp positions when fixing statements
  * gopls/internal/lsp/protocol/generate: restore indentation
  * gopls/internal/cmd: add 'execute' command
  * gopls/internal/test/marker: move ExitIfSmallMachine back to TestMain
  * gopls/internal/lsp/source/completion: support more postfix completion for map and slice (len, for, forr)
  * gopls/internal/server: simplify snapshot diagnostics
  * gopls/internal/lsp/server: simplify logic for diagnosing changed files
  * gopls/internal/test: move the tests
  * gopls/internal/lsp: remove lsp path segment
  * gopls/internal/util: more renamings
  * gopls/internal/analysis: rename lsp/analysis -> analysis
  * gopls: move marker tests to internal/test/marker
  * gopls/internal/server: superficial clean up of diagnostics
  * gopls/internal/lsp: delete dead code
  * gopls/protocol/generate: files to generate lsp stubs
  * gopls: update lsp stubs
  * gopls/internal/util: move lru,frob,bug,{ast,types,path}util here
  * gopls/internal/server: rename from lsp
  * gopls/internal/lsp/cache/metadata: rename Metadata to Package
  * gopls/internal/regtest: avoid file segments ending in a period
  * gopls/internal/lsp/cache: move ignoreFilter onto View
  * gopls/internal/lsp: remove analysisMode, and other unused params
  * gopls/internal/lsp: cleanups to view logic
  * gopls: remove unnecessary conversions
  * gopls/internal/lsp/source: fix hover for objects in unsafe
  * gopls/internal/lsp: invert the import between cache and source
  * gopls/internal/lsp/source: eliminate AnalyzerErrorKind
  * gopls/internal/lsp/cache: clean up more references to the source package
  * gopls/internal/lsp/source/typerefs: move to ../cache/typerefs
  * gopls/internal/lsp/source/methodsets: move to ../cache/methodsets
  * gopls/internal/lsp/source/xrefs: move to ../cache/xrefs
  * gopls/internal/lsp/cache: move parsing types / algorithm to parsego
  * gopls/internal/lsp/cache: split metadata related types into a package
  * gopls/internal/lsp/cache: move load diagnostics to packageHandle
  * gopls/internal/telemetry/cmd/stacks: skip gopls@devel
  * gopls/internal/lsp: factor showMessage calls
  * gopls: enable telemetry uploading only with 'serve'
  * gopls/internal/lsp/protocol: reject non-'file' scheme DocumentURIs
  * gopls/internal/lsp/source/extract: don't assume Scope.Pos
  * gopls/internal/lsp/source: move NodeContains into the astutil pkg
  * gopls/internal/lsp/cache: clean up unnecessary type checking indirection
  * gopls/internal/lsp/cache: don't rebuild filters for each modcache dir
  * gopls/internal/lsp/cache: move quick-fix bundling logic to the cache pkg
  * gopls/internal/cmd/help_test.go: document
  * gopls/internal/lsp/source: stubmethods: fix out-of-bounds index
  * gopls/internal/lsp/source: move edit logic into the protocol package
  * gopls/internal/lsp/cache: move SuggestedFixFromCommand into cache
  * gopls/internal/lsp/source: extract InDir to a new pathutil package
  * gopls/internal/lsp/cache: simplify named error values
  * gopls/internal/lsp/cache: use local aliases for all source objects
  * gopls/internal/lsp/cache: avoid problematic use of goCommandInvocation
  * gopls/internal/lsp/cache: remove workspaceMode
  * gopls: remove the "tempModFile" setting
  * gopls/internal/lsp: simplify mod update commands
  * gopls: simplify the Snapshot and View interfaces
  * gopls/internal/lsp/cache: export Snapshot
  * gopls/internal/lsp/source: remove View.Snapshot
  * gopls: remove the "chattyDiagnostics" setting
  * gopls: remove the LiteralCompletions option
  * gopls/internal/lsp/cache: move go.work parsing into the view
  * Revert "gopls/internal/lsp/source: fix rename spurious shadowing error"
  * gopls/internal/lsp: eliminate server code generation
  * gopls/internal/lsp/source: fix rename spurious shadowing error
  * gopls/test: eliminate, by moving tests to more appropriate places
  * gopls: move settings to a settings package
  * gopls: move file-related types to a 'file' package
  * gopls/internal/lsp/source: make source.Analyzer pure configuration
  * gopls/internal/lsp/source: fix panic in definition(error.Error)
  * gopls/internal/lsp: remove redundant conversions
  * gopls/internal/lsp/fake: inline fake.toURI away
  * gopls/internal/lsp/protocol: delete $GOROOT hack in URIFromPath
  * gopls/internal/lsp/protocol: rename URI.Filename -> Path
  * gopls/internal/lsp/protocol: inline .SpanURI() away
  * gopls/internal/lsp/protocol: inline URIFromSpanURI away
  * gopls/internal/lsp/span: inline URI away
  * gopls/internal/span: inline URIFromPath away
  * gopls/internal/telemetry/cmd/stacks: create GH issues from telemetry
  * gopls/internal/cmd: remove "span" import, make Span private
  * gopls/internal/span: identify span.URI and protocol.DocumentURI
  * gopls/internal/lsp: add code action for conversion between raw and interpreted string
  * gopls/internal/lsp/cache: rename workspaceInformation to viewDefinition
  * gopls/internal/lsp/cache: remove unused Session.ModifyFiles
  * gopls/internal/lsp/cache: move upgrades and vulns onto the snapshot
  * gopls/internal/lsp/cache: exclusively use persistent data in snapshot
  * Revert "gopls/internal/lsp/cache: remove baseCtx from the View"
  * all: add versions.InitFileVersions to gopls where needed
  * gopls: remove ineffectual skips
  * gopls/internal/span: delete SameExistingFile
  * gopls/internal/lsp/protocol: include docs for {,Document}URI
  * gopls/internal/cmd: move span.{Span,Point} to cmd
  * gopls: upgrade x/telemetry and account for new mode logic
  * gopls/internal/lsp/cache: avoid span.Parse{,InDir}
  * gopls/internal/goversion: split out of lsp (server) package
  * gopls/internal/lsp: tweak docs
  * gopls/internal/lsp/cmd: move to ../cmd
  * gopls/internal/lsp: move semantic token helpers to protocol pkg
  * gopls/internal/lsp: unexport Server
  * gopls/internal/lsp: restore Server.semanticTokens{Full,Range}
  * gopls/internal/lsp/source: fix panic on T(x) conversion
  * gopls/internal/lsp/regtest: minor clean up of marker.go
  * gopls/internal/lsp: unify semanticTokens{Full,Range}
  * gopls/internal/regtest/marker: port remaining marker tests
  * gopls/internal/regtest/marker: port the selectionrange markers
  * gopls/internal/regtest/marker: clean up some random packages
  * gopls/internal/lsp/tests: remove AddImport support
  * gopls/internal/regtest/marker: port the semantic tokens tests
  * gopls/internal/regtest/marker: port the inlay hint tests
  * gopls/internal/regtest/marker: port remaining rename tests
  * gopls/internal/regtest/marker: trim redundant header from golden diffs
  * gopls/internal/regtest/marker: use diffs for rename tests
  * gopls/internal/regtest/marker: porting remaining suggestedfix tests
  * gopls/internal/lsp/cmd: add codelens subcommand
  * gopls/internal/regtest/marker: use line-based myers diff implementation
  * gopls/internal/regtest/marker: port the stub tests
  * gopls/internal/regtest/marker: port the invertifcondition tests
  * gopls/internal/lsp/mod: clarify inlayhint comment
  * gopls/internal/regtest/marker: porting extract tests
  * gopls/internal/regtest/marker: use golden diffs for suggested fixes
  * gopls/internal/lsp/source: fix signatureHelp with pointer receivers
  * gopls/internal/lsp/cache: remove baseCtx from the View
  * gopls/internal/lsp/cache: remove forceReloadMetadata from clone
  * gopls/internal/lsp/cache: pass workspace information into createView
  * gopls/internal/lsp/cache: isolate getWorkspaceInformation from Session
  * gopls/internal/lsp/source: enable nilness Analyzer in gopls
  * gopls: remove dead code
  * gopls/internal/lsp/cache: allow duplicate analyzer names
  * gopls/internal/regtest/marker: port half of the suggestedfix markers
  * gopls/internal/lsp/cache: move 'contains' from snapshot to view
  * gopls/internal/lsp/cache: make options immutable on the View
  * gopls/internal/regtest/marker: port remaining rank and snippet tests
  * gopls/internal/regtest/marker: port remaining completion tests
  * gopls/internal/regtest/marker: port rank and func_rank tests
  * gopls/internal/regtest/marker: port builtin/keyword completion tests
  * gopls/internal/regtest/marker: port five arbitrary completion tests
  * gopls/internal/regtest/marker: port all prepare markers
  * gopls/internal/lsp: add OnSave diagnostics
  * gopls/internal/lsp/cmd: add GOPACKAGESDRIVER to stat
  * gopls/internal/regtest/marker: port the links marker
  * gopls/internal/regtest/marker: port case sensitive completion tests
  * gopls/internal/regtest/marker: port all deep and fuzzy completion tests
  * gopls/internal/regtest/marker: port statements completion tests
  * gopls/internal/regtest/marker: port remaining @signature markers
  * gopls/internal/lsp: fix code action panic on params of external funcs
  * gopls/internal/lsp/source: remove unused parameters (cleanup)
  * gopls/internal/lsp: add semantic highlighting for go: directives
- Packaging improvements:
  * Build PIE with pattern that may become recommended procedure:
    %%%%ifnarch ppc64 GOFLAGS="-buildmode=pie" %%%%endif go build
    A go toolchain buildmode default config would be preferable
    but none exist at this time.
  * Drop mod=vendor, go1.14+ will detect vendor dir and auto-enable
* Thu Nov 16 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 0.14.2:
  * gopls: update go.mod for v0.14.2-pre.1
  * gopls: upgrade x/telemetry and account for new mode logic
* Mon Oct 30 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 0.14.1:
  * gopls: update go.mod for v0.14.1-pre.1
  * gopls/internal/lsp: fix code action panic on params of external funcs
  * go/packages: don't fail if GOPACKAGESDRIVER leaves Compiler/GOARCH=""
* Wed Oct 25 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 0.14.0:
  * gopls: update go.mod for v0.14.0-pre.5
  * gopls/internal/lsp/source: find linkname directives without parsing
  * gopls/internal/lsp: fix signature crash on error.Error
  * gopls: update go.mod for v0.14.0-pre.4
  * gopls/internal/lsp/source: abort change signature on overlapping calls
  * gopls/internal/lsp: add code actions to remove unused parameters
  * gopls: deprecate "tempModfile" and "expandWorkspaceToModule" settings
  * gopls: update go.mod for v0.14.0-pre.3
  * gopls: upgrade x/telemetry dependency
  * gopls: allow all drive letters in cache/filemap_test.go
  * gopls/internal/lsp: use the correct options for semantic tokens legend
  * gopls: update go.mod for v0.14.0-pre.2
  * gopls/internal/lsp: go to definition from embed directive
  * gopls: update x/telemetry dependency
  * gopls/internal/lsp: simplify the telemetry prompt
  * gopls/internal/lsp/fake: don't set a completion budget for tests
  * gopls/internal/lsp: hover over embed directives
  * gopls/internal/lsp/cache: remove snapshot.typeCheckMu
  * gopls/internal/regtest/source/completion: reuse functionCallSnippet in unimported completion
  * gopls/internal/lsp: use matcher score in ranking unimported candidates
  * gopls/internal/lsp/source: don't complete to golang.org/toolchain
  * gopls/internal/lsp/source: Add ui.complete.completeFunctionCalls toggle
  * gopls: set a context deadline after minimal completion results
  * gopls: update go.mod for v0.14.0-pre.1
  * all: update codereview.cfg for gopls-release-branch.0.14
  * gopls: upgrade x/telemetry to latest
  * gopls/internal/lsp/source/completion: fixes for completion budget
  * gopls/internal/lsp/source/completion: start timing before type checking
  * gopls/internal/lsp: use linkifyShowMessage in telemetryOnMessage
  * gopls/internal/regtest/bench: add additional completion benchmarks
  * gopls/internal/lsp: update telemetry prompt and add a follow-up message
  * gopls/internal/lsp/command: add maybePromptForTelemetry
  * gopls/internal/lsp/source: add linkifyShowMessage (internal option)
  * gopls/internal/lsp/cmd: undocument gopls vulncheck
  * gopls/internal/lsp: update prompting logic for local/off mode
  * gopls: instrument telemetry for latency of important operations
  * all: register the appends analyzer in a few places and update gopls/go.mod
  * gopls: update golang.org/x/telemetry dependency
  * gopls/internal/lsp: minor cleanup to prompt logic
  * gopls/internal/lsp: add an idle prompt asking users to enable telemetry
  * gopls/internal/vulncheck/scan: buffer govulncheck STDERR output
  * gopls/internal/regtest/marker: rename to clarify marker types
  * gopls/internal/lsp/tests: eliminate several old marker types
  * gopls: update x/telemetry to the latest
  * gopls/internal: move builtin completion test to a regtest
  * gopls/internal/regtest: support full features of old completion markers
  * gopls/internal/lsp/source: inliner: don't spam log
  * gopls/lsp/command: add gopls.add_telemetry_counters
  * gopls: improve usage instructions for neovim
  * gopls/internal/regtest: port the codelens marker tests
  * gopls/internal/lsp/source: recover from inliner panics
  * gopls: update to use the new golang.org/x/vuln API
  * gopls/internal/lsp/regtest: parallelize marker tests
  * gopls/internal/lsp/regtest: port the highlight marker
  * gopls/internal/lsp: track didChangeConfiguration diagnostics for tests
  * gopls/internal/lsp: move options into the snapshot
  * gopls/internal/lsp/cache: move Option management to the Server
  * gopls/internal/regtest/marker: support folding ranges
  * gopls/internal/lsp/tests: eliminate the go1.18 summary file
  * gopls/internal/lsp/tests: simplify options
  * gopls/internal/lsp/cache: move working dir to workspaceInformation
  * gopls/internal/lsp/cache: simplify file change propagation
  * gopls/internal/lsp/cache: only evaluate fileMap.dirs when necessary
  * gopls/internal/lsp/cache: consolidate logic for updating maps in clone
  * gopls: update staticcheck (v0.4.5)
  * gopls/internal/lsp/cache: simplify tracking of snapshot directories
  * gopls/internal/lsp/cache: use persistent.Set in a couple places
  * gopls: add and enable the slog analyzer
  * gopls: tidy for 1.17+
  * gopls/internal/lsp/cmd: don't use x/exp/slices
  * gopls/internal/telemetry: don't schedule the next upload
  * gopls: remove dead code
  * gopls/internal/lsp/cache: delete unused mustEncode
  * gopls/internal/lsp/cmd: consolidate editing flags
  * gopls: more 1.18 cleanup; use strings.Cut and os functions
  * gopls/internal: move Options and FileKind from View to Snapshot
  * gopls: update uses of deprecated ioutil APIs
  * gopls/internal/lsp/analysis/unusedparams: document the blank identifier
  * gopls/internal/lsp/frob: add defensive header
  * gopls/internal/lsp/source: implement refactor.inline code action
  * gopls/internal/telemetry: log timestamp when test fails
  * gopls/internal/lsp/frob: fix build breakage
  * gopls/internal/lsp/frob: make API generic
  * gopls: update x/telemetry dependency
  * gopls/internal/lsp/debug: remove hard-coded version
  * gopls/doc: update tests that fail on Kokoro to run at Go 1.21+
  * gopls/internal/telemetry: write counter unconditionally and run upload
  * gopls/internal/lsp/mod: remove TestModfileRemainsUnchanged
  * gopls/internal/regtest/codelens: avoid a race in TestUpgradeCodelens
  * gopls/doc: include stderr output from 'go list' in pkgDir errors
  * gopls/internal/lsp: add testing support for the new zero builtin
  * gopls/internal/lsp/source completion: don't suggest untyped conversions
  * gopls/internal/lsp/source: fix implementations query on error type
  * gopls/internal/lsp/source: add a test for local types stubbing
  * gopls: stubbed methods shouldn't qualify the current package
  * gopls/internal/lsp/source: fix renaming instantiated fields
  * gopls/internal/lsp: switch default diff to "new"
  * gopls/telemetry: accept vscode-insiders as a known editor
  * gopls/internal/lsp/source/completion: add ifnotnil postfix snippet
  * gopls/internal/lsp/cache: avoid dependency on StdSizes
  * gopls: fix raciness related to TestOrphanedFiles
  * gopls/internal/lsp: avoid duplicate type checking following invalidation
  * gopls/internal/regtest/bench: skip oracle didSave test
  * gopls/telemetry: test that telemetry counters are written
  * gopls/internal/regtest/bench: enable oracle benchmarks with -short
  * go/types/objectpath: remove use of linkname for gopls back doors
  * gopls/internal/protocol: remove // line comments from tsprotocol.go
  * gopls/internal/regtest/bench: add an oracle completion benchmark
  * gopls/internal/telemetry: record Go version used in each view
  * gopls/internal/lsp/source: enable new defers analyzer
  * gopls/internal/bug: add gopls/bug telemetry counter
  * gopls: add gopls/client telemetry counters
* Tue Sep 12 2023 Lubos Kocman <lubos.kocman@suse.com>
- License correction based on legaldb review
  Add Apache-2.0 and MIT for vendor/gopkg.in/yaml.v3
* Thu Aug 17 2023 jkowalczyk@suse.com
- Update to version 0.13.2:
  * gopls: update go.mod for v0.13.2-pre.1
  * [gopls-release-branch.0.13] refactor/satisfy: (re)allow composite lits of pointer type
* Sat Aug 12 2023 jkowalczyk@suse.com
- Update to version 0.13.1:
  * gopls: update go.mod for v0.13.1-pre.2
  * gopls/internal/hooks: clean language version before passing to gofumpt
  * gopls/internal/lsp/analysis: fix stubmethods with variadic parameters
  * gopls: update go.mod for v0.13.1-pre.1
  * gopls/internal/lsp/source: reinstate equalOrigin for references check
  * gopls/internal/lsp/source: fix incorrect 'origin' logic for named types
  * gopls/internal/lsp/source: fix renaming of type parameters
  * gopls/internal/lsp/source: refresh embeddirective analyzer docs
* Mon Jul 31 2023 jkowalczyk@suse.com
- Update to version 0.13.0:
  * gopls: update go.mod for v0.13.0-pre.3
  * gopls/internal/lsp/source: Add SuggestedFix for embeddirective Analyzer
  * gopls/internal/lsp/cache: keep analysis progress reports on one line
  * gopls: update go.mod and go.sum for v0.13.0-pre.2
  * gopls/internal/lsp/cache: fast-path for type-checking active packages
  * gopls/internal/lsp/cache: fix use of time.NewTimer instead of NewTicker
  * gopls: fix tests that depend on log sequencing
  * gopls: update go.mod and go.sum for v0.13.0
  * gopls/internal/lsp/debug: update debug version for v0.13.0
  * all: update codereview.cfg for gopls-release-branch.0.13
  * gopls/internal/lsp/cache: use correct metadata in resolveImportGraph
  * gopls/internal/lsp/cache: fix incorrect check for active package
  * gopls/internal/lsp/source: highlight deprecated symbols
  * gopls/internal/lsp: don't recompute diagnostics during code actions
  * gopls/internal/lsp/cache: memoize active packages after every operation
  * gopls/internal/regtest/bench: add benchmarks for codeactions
  * gopls/internal/lsp/cache: fix boundary cond in parseCache age eviction
  * gopls/internal/lsp/cache: purge Analysis.Results earlier
  * gopls/internal/lsp/cache: limit parallelism
  * gopls/internal/lsp/cache: move purgeFuncBodies into the parse cache
  * gopls/internal/lsp/cache: used time-based eviction in parseCache
  * gopls/internal/lsp/frob: document another restriction
  * go/types/objectpath: avoid sorting methods for gopls
  * gopls/internal/lsp/cache: UX improvements for analysis
  * gopls/internal/lsp/cache: better panic if metadata invariant is broken
  * gopls/internal/lsp/cache: frob: a fast encoder with gob-like powers
  * gopls/internal/lsp: don't awaitLoaded inside resolveImportGraph
  * gopls/internal/lsp: fix a latent bug in orphaned file reloading
  * gopls/internal/lsp/source/typerefs: optimize getPackageHandles
  * gopls/internal/lsp: only diagnose one package per file
  * gopls/protocol/generate: upgrade generating LSP stubs
  * gopls/internal/lsp/debug: display Analysis.Run times
  * gopls/internal: update LSP support
  * gopls/internal/lsp/source: fix spurious "unexpected var object" error
  * gopls/internal/regtest/bench: add a test simulating typing
  * gopls/internal/regtest/bench: add an 'oracle' benchmark repo
  * gopls/internal/regtest/bench: clean up profile flags
  * gopls/internal/regtest/workspace: fix TestQuickFix_AddGoWork for go1.21
  * gopls: commands to start/stop profiling, and a new benchmark metric
  * gopls/internal/lsp/source: put context first in extracted functions
  * gopls/internal/lsp/source/completion: avoid duplicates from variants
  * gopls/internal/lsp: make gopls.start_debugging open browser
  * gopls/internal/lsp/filecache: increase idle GC period to 6 hours
  * gopls/internal/lsp/source/completion: honor usePlaceholders
  * gopls/internal/lsp/source/completion: placeholders for type params
  * gopls/internal/regtest/marker: skip addgowork.txt
  * gopls/internal/lsp/source/xrefs: include refs to methods of generics
  * gopls/internal/lsp/source: ignore objectpath error in rename
  * gopls: remove dead code
  * gopls/internal/lsp/cache: plumb analysis URLs to client
  * gopls/doc/contributing.md: document error handling strategies
  * gopls/internal/lsp/source/typerefs: move test into _test.go
  * gopls/internal/lsp/filecache: reduce GC frequency
  * gopls/internal/lsp/cmd: list bug reports in 'gopls bug'
  * gopls/internal/lsp/cache: don't panic when import fails during analysis
  * gopls/internal/lsp/cache: don't record edges to invalid packages
  * gopls/internal/lsp/cache: remove ITVs from shared import graph
* Mon Jun 26 2023 jkowalczyk@suse.com
- Update to version 0.12.4:
  * gopls/internal/lsp/cache: don't panic when import fails during analysis
  * gopls: update go.mod for v0.12.4
  * gopls/internal/lsp/cache: don't record edges to invalid packages
* Thu Jun 22 2023 jkowalczyk@suse.com
- Update to version 0.12.3:
  * gopls: update go.mod for v0.12.3
  * gopls/internal/lsp/cache: fix nil panic in analysis toSourceDiagnostic
  * gopls/internal/lsp/debug: update hard-coded version for v0.12.3
  * gopls/internal/lsp/cache: add debugging assertion for golang/go#60904
  * gopls/internal/lsp/cache: guard against "unsafe" by package path, not ID
  * gopls/internal/lsp/cache: use types.Unsafe in analysisPackage
  * gopls/internal/lsp/work: don't crash when hovering over broken mod dir
  * gopls/internal/lsp/cache: reduce importing in analysis
  * gopls/internal/regtest: fix goimports on windows when using vendoring
  * gopls/internal/lsp/source/completion: ensuring completion completeness
  * gopls/internal/regtest/codelens: set GOWORK=off for go mod vendor
  * gopls/internal/lsp/cache: two minor simplifications
  * gopls/internal/lsp/filecache: reduce lifespan of os.FileInfos
  * gopls/internal/lsp: enable min/max builtin completion test
* Mon Jun  5 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Refactor tarball unpacked sources layout with gopls/ as subdir.
  This allows us to include the LICENSE file at the upstream
  monorepo repository root. The changes required for the subdir
  layout are perhaps excessive for including just one metadata
  file, but serves as a good exercise for packaging other utilities
  under Go x/tools monorepo.
  * Upstream uses monorepo x/tools/ with gopls/ and others in subdirs
  * Upstream monorepo shared tools/LICENSE file in repository root dir
  * Move param subdir gopls usage from tar_scm to go_modules
  * tar_scm param include gopls and LICENSE
  * tar_scm param drop extraneous param exclude .git
  * Creates gopls-0.12.2.tar.gz unpacked layout gopls-0.12.2/gopls/go.mod
  * New layout requires moving LICENSE and vendor/ to subdir in %%prep
  * New layout requires change to subdir in %%build
  * New layout requires use path to subdir in %%check, %%install, %%files
* Mon Jun  5 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Initial package version 0.12.2:
  * Upstream uses monorepo x/tools/ with gopls/ and others in subdirs
  * service tar_scm use params subdir and filename both set to gopls
  * service go_modules_scm do not use any params
  * Creates gopls-0.12.2.tar.gz unpacked layout gopls-0.12.2/go.mod
  * Upstream monorepo shared tools/LICENSE file is one level above
    where we package
